@@ -4,6 +4,7 @@ ModelElement Blocks
 import kipet.model_components.ModelComponent as model_components
 from kipet.top_level.variable_names import VariableNames
 
+
 class ModelElementBlock():
     
     """Data abstraction for multiple ModelElement instances"""
@@ -69,9 +70,8 @@ class ModelElementBlock():
         return None
     
     def add_element(self, *args, **kwargs):
-        
-        """
-            
+        """General method to add model components to the model
+          
         """
         name = args[0]
         element = self.element_object(name,
@@ -197,6 +197,8 @@ class ComponentBlock(ModelElementBlock):
     
 class StateBlock(ModelElementBlock):
     
+    __var = VariableNames()
+    
     def __init__(self, *args, **kwargs):
         super().__init__(class_name='model_state')
     
@@ -248,6 +250,16 @@ class StateBlock(ModelElementBlock):
                 break
         return all_component_variances
     
+    @property
+    def fixed(self):
+        
+        fix_from_traj = []
+        for state in self.states.values():
+            if state.data is not None:
+                fix_from_traj.append([self.__var.state_model, state.name, state.data])
+        
+        return fix_from_traj
+    
     
 class ParameterBlock(ModelElementBlock):
     
